aboutsummaryrefslogtreecommitdiffstats
path: root/apps/settings
diff options
context:
space:
mode:
authorJohn Molakvoæ <skjnldsv@users.noreply.github.com>2024-02-13 21:28:00 +0100
committerGitHub <noreply@github.com>2024-02-13 21:28:00 +0100
commit6f1d9eb11880efb900370f1e6857f05dbef5f84a (patch)
tree906494fac943bd6ae4ecdf1e5460ee590e98afb1 /apps/settings
parentb63abdae8c1708693addf1dc3b2f862131e0299d (diff)
parent524ed97d621ded1aafa0f2f92670765af22ba55f (diff)
downloadnextcloud-server-6f1d9eb11880efb900370f1e6857f05dbef5f84a.tar.gz
nextcloud-server-6f1d9eb11880efb900370f1e6857f05dbef5f84a.zip
Merge pull request #34178 from nextcloud/replace-user-to-account-or-person
Rename users to account or person
Diffstat (limited to 'apps/settings')
-rw-r--r--apps/settings/lib/Controller/ChangePasswordController.php6
-rw-r--r--apps/settings/lib/Controller/MailSettingsController.php2
-rw-r--r--apps/settings/lib/Controller/UsersController.php4
-rw-r--r--apps/settings/lib/Mailer/NewUserMailHelper.php2
-rw-r--r--apps/settings/lib/Middleware/SubadminMiddleware.php2
-rw-r--r--apps/settings/lib/SetupChecks/CheckUserCertificates.php6
-rw-r--r--apps/settings/src/components/AdminTwoFactor.vue4
-rw-r--r--apps/settings/src/components/AppDetails.vue2
-rw-r--r--apps/settings/src/components/AuthTokenSetupDialog.vue2
-rw-r--r--apps/settings/src/components/BasicSettings/BackgroundJob.vue6
-rw-r--r--apps/settings/src/components/BasicSettings/ProfileSettings.vue2
-rw-r--r--apps/settings/src/components/GroupListItem.vue2
-rw-r--r--apps/settings/src/components/UserList.vue12
-rw-r--r--apps/settings/src/components/Users/UserRow.vue26
-rw-r--r--apps/settings/src/components/Users/UserRowActions.vue2
-rw-r--r--apps/settings/src/components/Users/UserSettingsDialog.vue6
-rw-r--r--apps/settings/src/constants/AccountPropertyConstants.js4
-rw-r--r--apps/settings/src/constants/ProfileConstants.js2
-rw-r--r--apps/settings/src/views/Users.vue14
-rw-r--r--apps/settings/templates/help.php4
-rw-r--r--apps/settings/templates/settings/admin/additional-mail.php2
-rw-r--r--apps/settings/tests/Controller/MailSettingsControllerTest.php2
-rw-r--r--apps/settings/tests/Mailer/NewUserMailHelperTest.php8
23 files changed, 61 insertions, 61 deletions
diff --git a/apps/settings/lib/Controller/ChangePasswordController.php b/apps/settings/lib/Controller/ChangePasswordController.php
index af4cf5969c9..50d72e582dd 100644
--- a/apps/settings/lib/Controller/ChangePasswordController.php
+++ b/apps/settings/lib/Controller/ChangePasswordController.php
@@ -132,7 +132,7 @@ class ChangePasswordController extends Controller {
return new JSONResponse([
'status' => 'error',
'data' => [
- 'message' => $this->l->t('No user supplied'),
+ 'message' => $this->l->t('No Login supplied'),
],
]);
}
@@ -186,7 +186,7 @@ class ChangePasswordController extends Controller {
return new JSONResponse([
'status' => 'error',
'data' => [
- 'message' => $this->l->t('Please provide an admin recovery password; otherwise, all user data will be lost.'),
+ 'message' => $this->l->t('Please provide an admin recovery password; otherwise, all account data will be lost.'),
]
]);
} elseif ($recoveryEnabledForUser && ! $validRecoveryPassword) {
@@ -212,7 +212,7 @@ class ChangePasswordController extends Controller {
return new JSONResponse([
'status' => 'error',
'data' => [
- 'message' => $this->l->t('Backend does not support password change, but the user\'s encryption key was updated.'),
+ 'message' => $this->l->t('Backend does not support password change, but the encryption of the account key was updated.'),
]
]);
} elseif (!$result && !$recoveryEnabledForUser) {
diff --git a/apps/settings/lib/Controller/MailSettingsController.php b/apps/settings/lib/Controller/MailSettingsController.php
index be662ed641a..c329de3cb6a 100644
--- a/apps/settings/lib/Controller/MailSettingsController.php
+++ b/apps/settings/lib/Controller/MailSettingsController.php
@@ -180,6 +180,6 @@ class MailSettingsController extends Controller {
}
$this->config->setAppValue('core', 'emailTestSuccessful', '0');
- return new DataResponse($this->l10n->t('You need to set your user email before being able to send test emails. Go to %s for that.', [$this->urlGenerator->linkToRouteAbsolute('settings.PersonalSettings.index')]), Http::STATUS_BAD_REQUEST);
+ return new DataResponse($this->l10n->t('You need to set your account email before being able to send test emails. Go to %s for that.', [$this->urlGenerator->linkToRouteAbsolute('settings.PersonalSettings.index')]), Http::STATUS_BAD_REQUEST);
}
}
diff --git a/apps/settings/lib/Controller/UsersController.php b/apps/settings/lib/Controller/UsersController.php
index 3c6ee1806f0..c6abe6bff4f 100644
--- a/apps/settings/lib/Controller/UsersController.php
+++ b/apps/settings/lib/Controller/UsersController.php
@@ -240,7 +240,7 @@ class UsersController extends Controller {
$disabledUsersGroup = [
'id' => 'disabled',
- 'name' => 'Disabled users',
+ 'name' => 'Disabled accounts',
'usercount' => $disabledUsers
];
@@ -388,7 +388,7 @@ class UsersController extends Controller {
[
'status' => 'error',
'data' => [
- 'message' => $this->l10n->t('Invalid user')
+ 'message' => $this->l10n->t('Invalid account')
]
],
Http::STATUS_UNAUTHORIZED
diff --git a/apps/settings/lib/Mailer/NewUserMailHelper.php b/apps/settings/lib/Mailer/NewUserMailHelper.php
index 69fb9a8e6cf..2d41577f554 100644
--- a/apps/settings/lib/Mailer/NewUserMailHelper.php
+++ b/apps/settings/lib/Mailer/NewUserMailHelper.php
@@ -134,7 +134,7 @@ class NewUserMailHelper {
}
$emailTemplate->addBodyText($l10n->t('Welcome to your %s account, you can add, protect, and share your data.', [$this->themingDefaults->getName()]));
if ($user->getBackendClassName() !== 'LDAP') {
- $emailTemplate->addBodyText($l10n->t('Your username is: %s', [$userId]));
+ $emailTemplate->addBodyText($l10n->t('Your Login is: %s', [$userId]));
}
if ($generatePasswordResetToken) {
$leftButtonText = $l10n->t('Set your password');
diff --git a/apps/settings/lib/Middleware/SubadminMiddleware.php b/apps/settings/lib/Middleware/SubadminMiddleware.php
index 782f0155510..d29d46ea62e 100644
--- a/apps/settings/lib/Middleware/SubadminMiddleware.php
+++ b/apps/settings/lib/Middleware/SubadminMiddleware.php
@@ -67,7 +67,7 @@ class SubadminMiddleware extends Middleware {
public function beforeController($controller, $methodName) {
if (!$this->reflector->hasAnnotation('NoSubAdminRequired') && !$this->reflector->hasAnnotation('AuthorizedAdminSetting')) {
if (!$this->isSubAdmin) {
- throw new NotAdminException($this->l10n->t('Logged in user must be a subadmin'));
+ throw new NotAdminException($this->l10n->t('Logged in account must be a subadmin'));
}
}
}
diff --git a/apps/settings/lib/SetupChecks/CheckUserCertificates.php b/apps/settings/lib/SetupChecks/CheckUserCertificates.php
index 8e9c0080a26..3f80b466201 100644
--- a/apps/settings/lib/SetupChecks/CheckUserCertificates.php
+++ b/apps/settings/lib/SetupChecks/CheckUserCertificates.php
@@ -46,7 +46,7 @@ class CheckUserCertificates implements ISetupCheck {
}
public function getName(): string {
- return $this->l10n->t('Old user imported certificates');
+ return $this->l10n->t('Old administration imported certificates');
}
public function run(): SetupResult {
@@ -55,8 +55,8 @@ class CheckUserCertificates implements ISetupCheck {
return SetupResult::success();
}
if ($this->configValue === 'not-run-yet') {
- return SetupResult::info($this->l10n->t('A background job is pending that checks for user imported SSL certificates. Please check back later.'));
+ return SetupResult::info($this->l10n->t('A background job is pending that checks for administration imported SSL certificates. Please check back later.'));
}
- return SetupResult::error($this->l10n->t('There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via "occ security:certificates:import" command. Their paths inside the data directory are shown below.'));
+ return SetupResult::error($this->l10n->t('There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via "occ security:certificates:import" command. Their paths inside the data directory are shown below.'));
}
}
diff --git a/apps/settings/src/components/AdminTwoFactor.vue b/apps/settings/src/components/AdminTwoFactor.vue
index aba6dc7537f..f2572be9c90 100644
--- a/apps/settings/src/components/AdminTwoFactor.vue
+++ b/apps/settings/src/components/AdminTwoFactor.vue
@@ -1,6 +1,6 @@
<template>
<NcSettingsSection :name="t('settings', 'Two-Factor Authentication')"
- :description="t('settings', 'Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.')"
+ :description="t('settings', 'Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.')"
:doc-url="twoFactorAdminDoc">
<p v-if="loading">
<span class="icon-loading-small two-factor-loading" />
@@ -50,7 +50,7 @@
<p class="top-margin">
<em>
<!-- this text is also found in the documentation. update it there as well if it ever changes -->
- {{ t('settings', 'When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.') }}
+ {{ t('settings', 'When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.') }}
</em>
</p>
</template>
diff --git a/apps/settings/src/components/AppDetails.vue b/apps/settings/src/components/AppDetails.vue
index 0440741f4c9..0f9969c650b 100644
--- a/apps/settings/src/components/AppDetails.vue
+++ b/apps/settings/src/components/AppDetails.vue
@@ -130,7 +130,7 @@
class="appslink"
:href="app.documentation.user"
target="_blank"
- rel="noreferrer noopener">{{ t('settings', 'User documentation') }} ↗</a>
+ rel="noreferrer noopener">{{ t('settings', 'Usage documentation') }} ↗</a>
<a v-if="app.documentation && app.documentation.admin"
class="appslink"
:href="app.documentation.admin"
diff --git a/apps/settings/src/components/AuthTokenSetupDialog.vue b/apps/settings/src/components/AuthTokenSetupDialog.vue
index f40fe722cef..20e3b29d0f1 100644
--- a/apps/settings/src/components/AuthTokenSetupDialog.vue
+++ b/apps/settings/src/components/AuthTokenSetupDialog.vue
@@ -27,7 +27,7 @@
{{ t('settings', 'Use the credentials below to configure your app or device. For security reasons this password will only be shown once.') }}
</p>
<div class="token-dialog__name">
- <NcTextField :label="t('settings', 'Username')" :value="loginName" readonly />
+ <NcTextField :label="t('settings', 'Login')" :value="loginName" readonly />
<NcButton type="tertiary"
:title="copyLoginNameLabel"
:aria-label="copyLoginNameLabel"
diff --git a/apps/settings/src/components/BasicSettings/BackgroundJob.vue b/apps/settings/src/components/BasicSettings/BackgroundJob.vue
index 04ef607e03b..c19eac47889 100644
--- a/apps/settings/src/components/BasicSettings/BackgroundJob.vue
+++ b/apps/settings/src/components/BasicSettings/BackgroundJob.vue
@@ -54,7 +54,7 @@
@update:checked="onBackgroundJobModeChanged">
{{ t('settings', 'AJAX') }}
</NcCheckboxRadioSwitch>
- <em>{{ t('settings', 'Execute one task with each page loaded. Use case: Single user instance.') }}</em>
+ <em>{{ t('settings', 'Execute one task with each page loaded. Use case: Single account instance.') }}</em>
<NcCheckboxRadioSwitch type="radio"
:checked.sync="backgroundJobsMode"
@@ -63,7 +63,7 @@
@update:checked="onBackgroundJobModeChanged">
{{ t('settings', 'Webcron') }}
</NcCheckboxRadioSwitch>
- <em>{{ t('settings', 'cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage).') }}</em>
+ <em>{{ t('settings', 'cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage).') }}</em>
<NcCheckboxRadioSwitch type="radio"
:disabled="!cliBasedCronPossible"
@@ -121,7 +121,7 @@ export default {
cronLabel() {
let desc = t('settings', 'Use system cron service to call the cron.php file every 5 minutes.')
if (this.cliBasedCronPossible) {
- desc += '<br>' + t('settings', 'The cron.php needs to be executed by the system user "{user}".', { user: this.cliBasedCronUser })
+ desc += '<br>' + t('settings', 'The cron.php needs to be executed by the system account "{user}".', { user: this.cliBasedCronUser })
} else {
desc += '<br>' + t('settings', 'The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.', {
linkstart: '<a target="_blank" rel="noreferrer nofollow" class="external" href="https://www.php.net/manual/en/book.posix.php">',
diff --git a/apps/settings/src/components/BasicSettings/ProfileSettings.vue b/apps/settings/src/components/BasicSettings/ProfileSettings.vue
index 8b63940e257..40cb83d98fe 100644
--- a/apps/settings/src/components/BasicSettings/ProfileSettings.vue
+++ b/apps/settings/src/components/BasicSettings/ProfileSettings.vue
@@ -28,7 +28,7 @@
</h2>
<p class="settings-hint">
- {{ t('settings', 'Enable or disable profile by default for new users.') }}
+ {{ t('settings', 'Enable or disable profile by default for new accounts.') }}
</p>
<NcCheckboxRadioSwitch type="switch"
diff --git a/apps/settings/src/components/GroupListItem.vue b/apps/settings/src/components/GroupListItem.vue
index cba0b7b3748..ca50b38b200 100644
--- a/apps/settings/src/components/GroupListItem.vue
+++ b/apps/settings/src/components/GroupListItem.vue
@@ -30,7 +30,7 @@
</h2>
<NcNoteCard type="warning"
show-alert>
- {{ t('settings', 'You are about to remove the group "{group}". The users will NOT be deleted.', { group: name }) }}
+ {{ t('settings', 'You are about to remove the group "{group}". The accounts will NOT be deleted.', { group: name }) }}
</NcNoteCard>
<div class="modal__button-row">
<NcButton type="secondary"
diff --git a/apps/settings/src/components/UserList.vue b/apps/settings/src/components/UserList.vue
index 92c823e8bc5..73c4c3bdfec 100644
--- a/apps/settings/src/components/UserList.vue
+++ b/apps/settings/src/components/UserList.vue
@@ -31,10 +31,10 @@
<NcEmptyContent v-if="filteredUsers.length === 0"
class="empty"
- :name="isInitialLoad && loading.users ? null : t('settings', 'No users')">
+ :name="isInitialLoad && loading.users ? null : t('settings', 'No accounts')">
<template #icon>
<NcLoadingIcon v-if="isInitialLoad && loading.users"
- :name="t('settings', 'Loading users …')"
+ :name="t('settings', 'Loading accounts …')"
:size="64" />
<NcIconSvgWrapper v-else
:svg="usersSvg" />
@@ -61,7 +61,7 @@
@scroll-end="handleScrollEnd">
<template #before>
<caption class="hidden-visually">
- {{ t('settings', 'List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.') }}
+ {{ t('settings', 'List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list.') }}
</caption>
</template>
@@ -320,8 +320,8 @@ export default {
}
logger.debug(`${this.users.length} total user(s) loaded`)
} catch (error) {
- logger.error('Failed to load users', { error })
- showError('Failed to load users')
+ logger.error('Failed to load accounts', { error })
+ showError('Failed to load accounts')
}
this.loading.users = false
this.isInitialLoad = false
@@ -368,7 +368,7 @@ export default {
setNewUserDefaultGroup(value) {
if (value && value.length > 0) {
- // setting new user default group to the current selected one
+ // setting new account default group to the current selected one
const currentGroup = this.groups.find(group => group.id === value)
if (currentGroup) {
this.newUser.groups = [currentGroup]
diff --git a/apps/settings/src/components/Users/UserRowActions.vue b/apps/settings/src/components/Users/UserRowActions.vue
index b135f80cf7b..a01bb868c7a 100644
--- a/apps/settings/src/components/Users/UserRowActions.vue
+++ b/apps/settings/src/components/Users/UserRowActions.vue
@@ -22,7 +22,7 @@
-->
<template>
- <NcActions :aria-label="t('settings', 'Toggle user actions menu')"
+ <NcActions :aria-label="t('settings', 'Toggle account actions menu')"
:disabled="disabled"
:inline="1">
<NcActionButton :data-cy-user-list-action-toggle-edit="`${edit}`"
diff --git a/apps/settings/src/components/Users/UserSettingsDialog.vue b/apps/settings/src/components/Users/UserSettingsDialog.vue
index 79f7d72c5d5..26659e85b5e 100644
--- a/apps/settings/src/components/Users/UserSettingsDialog.vue
+++ b/apps/settings/src/components/Users/UserSettingsDialog.vue
@@ -23,7 +23,7 @@
<template>
<NcAppSettingsDialog :open.sync="isModalOpen"
:show-navigation="true"
- :name="t('settings', 'User management settings')">
+ :name="t('settings', 'Account management settings')">
<NcAppSettingsSection id="visibility-settings"
:name="t('settings', 'Visibility')">
<NcCheckboxRadioSwitch type="switch"
@@ -34,7 +34,7 @@
<NcCheckboxRadioSwitch type="switch"
data-test="showUserBackend"
:checked.sync="showUserBackend">
- {{ t('settings', 'Show user backend') }}
+ {{ t('settings', 'Show account backend') }}
</NcCheckboxRadioSwitch>
<NcCheckboxRadioSwitch type="switch"
data-test="showStoragePath"
@@ -54,7 +54,7 @@
data-test="sendWelcomeMail"
:checked.sync="sendWelcomeMail"
:disabled="loadingSendMail">
- {{ t('settings', 'Send welcome email to new users') }}
+ {{ t('settings', 'Send welcome email to new accounts') }}
</NcCheckboxRadioSwitch>
</NcAppSettingsSection>
diff --git a/apps/settings/src/constants/AccountPropertyConstants.js b/apps/settings/src/constants/AccountPropertyConstants.js
index 04367fde811..eb35482fb32 100644
--- a/apps/settings/src/constants/AccountPropertyConstants.js
+++ b/apps/settings/src/constants/AccountPropertyConstants.js
@@ -180,14 +180,14 @@ export const SCOPE_PROPERTY_ENUM = Object.freeze({
name: SCOPE_ENUM.FEDERATED,
displayName: t('settings', 'Federated'),
tooltip: t('settings', 'Only synchronize to trusted servers'),
- tooltipDisabled: t('settings', 'Not available as federation has been disabled for your account, contact your system administrator if you have any questions'),
+ tooltipDisabled: t('settings', 'Not available as federation has been disabled for your account, contact your system administration if you have any questions'),
iconClass: 'icon-contacts-dark',
},
[SCOPE_ENUM.PUBLISHED]: {
name: SCOPE_ENUM.PUBLISHED,
displayName: t('settings', 'Published'),
tooltip: t('settings', 'Synchronize to trusted servers and the global and public address book'),
- tooltipDisabled: t('settings', 'Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions'),
+ tooltipDisabled: t('settings', 'Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions'),
iconClass: 'icon-link',
},
})
diff --git a/apps/settings/src/constants/ProfileConstants.js b/apps/settings/src/constants/ProfileConstants.js
index f9fd3d26fb7..f2b831bc496 100644
--- a/apps/settings/src/constants/ProfileConstants.js
+++ b/apps/settings/src/constants/ProfileConstants.js
@@ -41,7 +41,7 @@ export const VISIBILITY_PROPERTY_ENUM = Object.freeze({
},
[VISIBILITY_ENUM.SHOW_USERS_ONLY]: {
name: VISIBILITY_ENUM.SHOW_USERS_ONLY,
- label: t('settings', 'Show to logged in users only'),
+ label: t('settings', 'Show to logged in accounts only'),
},
[VISIBILITY_ENUM.HIDE]: {
name: VISIBILITY_ENUM.HIDE,
diff --git a/apps/settings/src/views/Users.vue b/apps/settings/src/views/Users.vue
index dc17b9f9362..1975dc9acf0 100644
--- a/apps/settings/src/views/Users.vue
+++ b/apps/settings/src/views/Users.vue
@@ -23,9 +23,9 @@
<template>
<Fragment>
<NcContent app-name="settings">
- <NcAppNavigation :aria-label="t('settings', 'User management')">
+ <NcAppNavigation :aria-label="t('settings', 'Account management')">
<NcAppNavigationNew button-id="new-user-button"
- :text="t('settings','New user')"
+ :text="t('settings','New account')"
@click="showNewUserMenu"
@keyup.enter="showNewUserMenu"
@keyup.space="showNewUserMenu">
@@ -37,7 +37,7 @@
<template #list>
<NcAppNavigationItem id="everyone"
:exact="true"
- :name="t('settings', 'Active users')"
+ :name="t('settings', 'Active accounts')"
:to="{ name: 'users' }">
<template #icon>
<AccountGroup :size="20" />
@@ -117,7 +117,7 @@
<template #footer>
<ul class="app-navigation-entry__settings">
- <NcAppNavigationItem :name="t('settings', 'User management settings')"
+ <NcAppNavigationItem :name="t('settings', 'Account management settings')"
@click="isDialogOpen = true">
<template #icon>
<Cog :size="20" />
@@ -214,13 +214,13 @@ export default {
computed: {
pageHeading() {
if (this.selectedGroupDecoded === null) {
- return t('settings', 'Active users')
+ return t('settings', 'Active accounts')
}
const matchHeading = {
admin: t('settings', 'Admins'),
- disabled: t('settings', 'Disabled users'),
+ disabled: t('settings', 'Disabled accounts'),
}
- return matchHeading[this.selectedGroupDecoded] ?? t('settings', 'User group: {group}', { group: this.selectedGroupDecoded })
+ return matchHeading[this.selectedGroupDecoded] ?? t('settings', 'Account group: {group}', { group: this.selectedGroupDecoded })
},
showConfig() {
diff --git a/apps/settings/templates/help.php b/apps/settings/templates/help.php
index 649178c15d1..1b912d3d904 100644
--- a/apps/settings/templates/help.php
+++ b/apps/settings/templates/help.php
@@ -12,7 +12,7 @@
} ?>
href="<?php print_unescaped($_['urlUserDocs']); ?>">
<span class="help-list__text">
- <?php p($l->t('User documentation')); ?>
+ <?php p($l->t('Account documentation')); ?>
</span>
</a>
</li>
@@ -25,7 +25,7 @@
} ?>
href="<?php print_unescaped($_['urlAdminDocs']); ?>">
<span class="help-list__text">
- <?php p($l->t('Administrator documentation')); ?>
+ <?php p($l->t('Administration documentation')); ?>
</span>
</a>
</li>
diff --git a/apps/settings/templates/settings/admin/additional-mail.php b/apps/settings/templates/settings/admin/additional-mail.php
index 3e8b373c738..3d418740963 100644
--- a/apps/settings/templates/settings/admin/additional-mail.php
+++ b/apps/settings/templates/settings/admin/additional-mail.php
@@ -148,7 +148,7 @@ $mail_sendmailmode = [
print_unescaped(' class="hidden"');
} ?>>
<label for="mail_smtpname"><?php p($l->t('Credentials')); ?></label>
- <input type="text" name="mail_smtpname" id="mail_smtpname" placeholder="<?php p($l->t('SMTP Username'))?>"
+ <input type="text" name="mail_smtpname" id="mail_smtpname" placeholder="<?php p($l->t('SMTP Login'))?>"
value="<?php p($_['mail_smtpname']) ?>" />
<input type="text" name="mail_smtppassword" id="mail_smtppassword" autocomplete="off"
placeholder="<?php p($l->t('SMTP Password'))?>" value="<?php p($_['mail_smtppassword']) ?>" />
diff --git a/apps/settings/tests/Controller/MailSettingsControllerTest.php b/apps/settings/tests/Controller/MailSettingsControllerTest.php
index bfa89fbc0b4..3918d4b5fa9 100644
--- a/apps/settings/tests/Controller/MailSettingsControllerTest.php
+++ b/apps/settings/tests/Controller/MailSettingsControllerTest.php
@@ -171,7 +171,7 @@ class MailSettingsControllerTest extends \Test\TestCase {
// Ensure that it fails when no mail address has been specified
$response = $this->mailController->sendTestMail();
$this->assertSame(Http::STATUS_BAD_REQUEST, $response->getStatus());
- $this->assertSame('You need to set your user email before being able to send test emails. Go to for that.', $response->getData());
+ $this->assertSame('You need to set your account email before being able to send test emails. Go to for that.', $response->getData());
// If no exception is thrown it should work
$this->config
diff --git a/apps/settings/tests/Mailer/NewUserMailHelperTest.php b/apps/settings/tests/Mailer/NewUserMailHelperTest.php
index 5c7d182d436..d4ab5c10692 100644
--- a/apps/settings/tests/Mailer/NewUserMailHelperTest.php
+++ b/apps/settings/tests/Mailer/NewUserMailHelperTest.php
@@ -262,7 +262,7 @@ class NewUserMailHelperTest extends TestCase {
<table style="border-collapse:collapse;border-spacing:0;padding:0;text-align:left;vertical-align:top;width:100%">
<tr style="padding:0;text-align:left;vertical-align:top">
<th style="Margin:0;color:#0a0a0a;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;padding:0;text-align:left">
- <p style="Margin:0;Margin-bottom:10px;color:#777;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Your username is: john</p>
+ <p style="Margin:0;Margin-bottom:10px;color:#777;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Your Login is: john</p>
</th>
<th class="expander" style="Margin:0;color:#0a0a0a;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;padding:0!important;text-align:left;visibility:hidden;width:0"></th>
</tr>
@@ -363,7 +363,7 @@ Welcome aboard
Welcome to your TestCloud account, you can add, protect, and share your data.
-Your username is: john
+Your Login is: john
Set your password: https://example.com/resetPassword/MySuperLongSecureRandomToken
@@ -498,7 +498,7 @@ EOF;
<table style="border-collapse:collapse;border-spacing:0;padding:0;text-align:left;vertical-align:top;width:100%">
<tr style="padding:0;text-align:left;vertical-align:top">
<th style="Margin:0;color:#0a0a0a;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;padding:0;text-align:left">
- <p style="Margin:0;Margin-bottom:10px;color:#777;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Your username is: john</p>
+ <p style="Margin:0;Margin-bottom:10px;color:#777;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Your Login is: john</p>
</th>
<th class="expander" style="Margin:0;color:#0a0a0a;font-family:-apple-system,BlinkMacSystemFont,'Segoe UI',Roboto,Oxygen-Sans,Ubuntu,Cantarell,'Helvetica Neue',Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;padding:0!important;text-align:left;visibility:hidden;width:0"></th>
</tr>
@@ -599,7 +599,7 @@ Welcome aboard John Doe
Welcome to your TestCloud account, you can add, protect, and share your data.
-Your username is: john
+Your Login is: john
Go to TestCloud: https://example.com/
diff --git a/apps/settings/src/components/Users/UserRow.vue b/apps/settings/src/components/Users/UserRow.vue
index a27b41e11a6..179ec8956e4 100644
--- a/apps/settings/src/components/Users/UserRow.vue
+++ b/apps/settings/src/components/Users/UserRow.vue
@@ -28,7 +28,7 @@
:data-cy-user-row="user.id">
<td class="row__cell row__cell--avatar" data-cy-user-list-cell-avatar>
<NcLoadingIcon v-if="isLoadingUser"
- :name="t('settings', 'Loading user …')"
+ :name="t('settings', 'Loading account …')"
:size="32" />
<NcAvatar v-else-if="visible"
disable-menu
@@ -87,7 +87,7 @@
@trailing-button-click="updatePassword" />
</template>
<span v-else-if="isObfuscated">
- {{ t('settings', 'You do not have permissions to see the details of this user') }}
+ {{ t('settings', 'You do not have permissions to see the details of this account') }}
</span>
</td>
@@ -130,7 +130,7 @@
:multiple="true"
:append-to-body="false"
:options="availableGroups"
- :placeholder="t('settings', 'Add user to group')"
+ :placeholder="t('settings', 'Add account to group')"
:taggable="settings.isAdmin"
:value="userGroups"
label="name"
@@ -152,7 +152,7 @@
<template v-if="editing && settings.isAdmin && subAdminsGroups.length > 0">
<label class="hidden-visually"
:for="'subadmins' + uniqueId">
- {{ t('settings', 'Set user as admin for') }}
+ {{ t('settings', 'Set account as admin for') }}
</label>
<NcSelect data-cy-user-list-input-subadmins
:data-loading="loading.subadmins || undefined"
@@ -165,7 +165,7 @@
:multiple="true"
:no-wrap="true"
:options="subAdminsGroups"
- :placeholder="t('settings', 'Set user as admin for')"
+ :placeholder="t('settings', 'Set account as admin for')"
:value="userSubAdminsGroups"
@option:deselected="removeUserSubAdmin"
@option:selected="options => addUserSubAdmin(options.at(-1))" />
@@ -180,7 +180,7 @@
<template v-if="editing">
<label class="hidden-visually"
:for="'quota' + uniqueId">
- {{ t('settings', 'Select user quota') }}
+ {{ t('settings', 'Select account quota') }}
</label>
<NcSelect v-model="editedUserQuota"
:close-on-select="true"
@@ -193,7 +193,7 @@
:clearable="false"
:input-id="'quota' + uniqueId"
:options="quotaOptions"
- :placeholder="t('settings', 'Select user quota')"
+ :placeholder="t('settings', 'Select account quota')"
:taggable="true"
@option:selected="setUserQuota" />
</template>
@@ -398,8 +398,8 @@ export default {
computed: {
managerLabel() {
- // TRANSLATORS This string describes a manager in the context of an organization
- return t('settings', 'Set user manager')
+ // TRANSLATORS This string describes a person's manager in the context of an organization
+ return t('settings', 'Set line manager')
},
isObfuscated() {
@@ -469,7 +469,7 @@ export default {
const actions = [
{
icon: 'icon-delete',
- text: t('settings', 'Delete user'),
+ text: t('settings', 'Delete account'),
action: this.deleteUser,
},
{
@@ -479,7 +479,7 @@ export default {
},
{
icon: this.user.enabled ? 'icon-close' : 'icon-add',
- text: this.user.enabled ? t('settings', 'Disable user') : t('settings', 'Enable user'),
+ text: this.user.enabled ? t('settings', 'Disable account') : t('settings', 'Enable account'),
action: this.enableDisableUser,
},
]
@@ -586,8 +586,8 @@ export default {
value: this.currentManager ? this.currentManager.id : '',
})
} catch (error) {
- // TRANSLATORS This string describes a manager in the context of an organization
- showError(t('setting', 'Failed to update user manager'))
+ // TRANSLATORS This string describes a line manager in the context of an organization
+ showError(t('setting', 'Failed to update line manager'))
console.error(error)
} finally {
this.loading.manager = false